function CSD2save = ComputeAndDrawCSD(Flags, Fs, T0, Channels, s, V, Type2deriv, PlotPresision)
%
% Compute and plot CSD for generators (s, V must be there) or for LFPs (s =
% LFP)
%

if nargin < 8 || isempty(PlotPresision), PlotPresision = 1; end

if isempty(Channels), 
    errordlg('Wrong channels selected','warning','modal');
    return;
end
if size(Channels,1) == 1,
    idChns = Channels;
else
    idChns = Channels(2,:);
    Channels = Channels(1,:);
end

Tlim = get(gca,'Xlim');
t1 = max(1,round((Tlim(1) - T0)*Fs));
t2 = min(round((Tlim(2) - T0)*Fs),size(s,2));

if PlotPresision == 1
    tt = unique(round(linspace(t1,t2,600)));
elseif PlotPresision == 2
    tt = unique(round(linspace(t1,t2,1200)));
else    
    tt = t1:t2;
end

if isempty(V),
    % LFP CSD
    F_ColorLimits = str2num(Flags{1}); 
    nClGrs = str2num(Flags{2}); % number of colors
    F_PlotGrid = strcmpi(Flags{3},'yes');
    Img = -Derivative_1D(s(:,tt), Type2deriv);
else
    % Generator's CSD
    nGnr = intersect(1:size(s,1),str2num(Flags{1}));   % selected generators
    F_ColorLimits = str2num(Flags{2}); 
    nClGrs = str2num(Flags{3}); % number of colors
    F_SubtrMedian = strcmpi(Flags{4},'yes');
    F_PlotGrid = strcmpi(Flags{5},'yes');
    if isempty(V),
        Img = s(:,tt);
    else
        if F_SubtrMedian,
            ss = s(nGnr,tt) - median(s(nGnr,tt),2)*ones(1,size(s(nGnr,tt),2));
            Img = -Derivative_1D(V(:,nGnr), Type2deriv)*ss;
        else
            Img = -Derivative_1D(V(:,nGnr), Type2deriv)*s(nGnr,tt);
        end
    end
end
if isempty(Img),
    errordlg('No image to display. Check time interval.','warning','modal');
    return;
end 
if isempty(F_ColorLimits)
    Cmax = max(abs(Img(:)))*[-1 1];
else
    F_ColorLimits = abs(F_ColorLimits(1));
    Cmax = F_ColorLimits*[-1 1];
end
vv = linspace(Cmax(1),Cmax(2), nClGrs);

if length(tt) > 1200, 
    step = floor(length(tt)/1200); 
else
    step = 1;
end

contourf(T0 + tt(1:step:end)/Fs, Channels, Img(idChns,1:step:end), vv, 'LineColor', 'none');
set(gca,'YDir','reverse')
set(gca,'CLim',Cmax)
colorbar('location','East')
colormap('jet')
if F_PlotGrid, grid on; end

if nargout ~= 0,
    CSD2save.CSD = Img(idChns,:);
    CSD2save.Time = T0 + tt/Fs;
    CSD2save.Chanels = Channels;
end


