function idCluster = DelimitClusters(WTC)
% 
% This function intereactively delimit clusters of spikes 
%
%

clr = 'bgrcmyk';
nX = 300;
nY = 200;

Xl = [min(WTC(:,1)), max(WTC(:,1))];
Yl = [min(WTC(:,2)), max(WTC(:,2))];
xx = linspace(Xl(1), Xl(2), nX);
yy = linspace(Yl(1), Yl(2), nY);
Im = zeros(nY, nX);
for k = 1:nY-1
    id = yy(k) <= WTC(:,2) &  WTC(:,2) <= yy(k+1);   
    Im(nY-k,:) = histc(WTC(id,1),xx);
end
imagesc(xx,yy,flipud(log(Im+1)))
set(gca,'YDir','normal')
colormap('hot')
hold on
title('Use mouse to draw a poligon that includes spikes in a cluster (right botton to close)')

Cluster = 1;

while Cluster ~= 0,
    % define boundary
    [xi,yi,but] = ginput(1);
    xy = [xi;yi];
    plot(xi,yi,'yo');
    while but == 1
        [xi,yi,but] = ginput(1); % read pointer position
        plot([xy(1,end);xi],[xy(2,end);yi],'yo-');
        xy =[xy [xi;yi]];
    end
    plot([xy(1,end);xy(1,1)],[xy(2,end);xy(2,1)],'yo-'); % close the polygon
    
    % define spikes belonging to the cluster
    if size(xy, 2) > 2,
        isptin = find(isinpoly(WTC(:,1), WTC(:,2), xy(1,:), xy(2,:)) == 1);
        if ~isempty(isptin),
            plot(WTC(isptin,1), WTC(isptin,2),[clr(Cluster) '.']);
            idCluster{Cluster} = isptin;
            ButtonName = questdlg('Add new cluster?', 'Choice', 'Yes', 'No', 'Yes');
            if strcmpi(ButtonName,'Yes')
                Cluster = Cluster + 1;
            else
                Cluster = 0;
            end
        end
    end
end
