function Tsp = DetectSpikeTimes(s, fs, alpha)
%
% Detect spike instants. Recording is high pass filtered and 
% then a threshold is used (depends on the noise strength)  
%
%
%   s      1D signal
%   alpha  Threshold multiplyer
%
%   Tsp    spike times (in points)
%
%

FilterBank.Notch = [];
FilterBank.LPF = [];
FilterBank.HPF = 300;      
s = FilterLFPs(s, fs, FilterBank); % High Pass Filter 

Vthr = alpha*median(abs(s))/0.6745;       % set negative threshold
Tsp = find((s(1:end-1) + Vthr) > 0 & (s(2:end) + Vthr) <= 0); 

