function G = GroupLoadings(G, Distance)


V = G.V;
d = HilbertDistance(V, Distance);
Z = linkage(d, 'average');
%D = squareform(d);
% [Y,e] = cmdscale(D); 
% Y = mdscale(D,2,'criterion','sammon');

dendrogram(Z,0);
[~, Th] = ginput(1);
if Th < 0 || Th > 1, Th = 0; end
dendrogram(Z, 0, 'colorthreshold', Th);
% hold on
% plot([x1 x1],ylm,'color',[0.8,0.6,0.6],'LineWidth',2);
T = cluster(Z,'cutoff', Th, 'criterion','distance');
cl = unique(T);
nCls = length(cl);
ClSz = zeros(1,nCls);
for k = 1:nCls,
    ClSz(k) = sum(T == cl(k));
end
[~,idx] = sort(ClSz,'descend');
cl = cl(idx);

r = zeros(size(V,1),nCls);
sz = get(0, 'ScreenSize'); % get screen size
h = figure('color','w','position',[0.1*[sz(3) sz(4)] 0.8*[sz(3) sz(4)]]);
subplot(2,4,[1 2 3])
dendrogram(Z, 0, 'colorthreshold', Th);
ylim([0,0.6])
clr = 'bgrcymk';
for k = 1:nCls,
    v = NormalizeCurves(V(:,T == cl(k)));
    if size(v,2) > 1
        %define sign for loadings
        d = 1 - abs(1-pdist(v','cosine'));
        [~,id] = min(sum(squareform(d))); % index of the best curve
        % invert [*(-1)] wrong oriented curves 
        SIG = 2*(sum(abs(v - v(:,id)*ones(1,size(v,2)))) ...
            - sum(abs(v + v(:,id)*ones(1,size(v,2)))) < 0) - 1;
        v = v.*(ones(size(v,1),1)*SIG);
        % find loading template
        [~, j] = max(abs(sum(v,2))); % max index to avoid divide by 0
        r(:,k) = mean(v(j,:))*sum(v,2)/sum(v(j,:));
    else
        r(:,k) = v;
    end        
    if k <= 5
        subplot(2,4,k+3)
        plot(v,'k'); 
        hold on
        plot(r(:,k),[clr(k) 'o-'],'LineWidth',2)
        title(['G' num2str(k) ': ' num2str(size(v,2)) ' loadings'])
        xlim([1,size(v,1)])
    end
end
r = NormalizeCurves(r);
X = G.V*G.s;
G.V = r;
G.s = pinv(r)*X;
G.ID = 1:nCls;
if strcmpi(computer,'pcwin')
    print(['-f' num2str(h)],'-dmeta')
    str = ['Loadings have been groupped into '...
        num2str(length(G.ID)) ' clusters. The figure is copied into CLIPBOARD, Ctrl+v to paste'];
    uiwait(msgbox(str));
    close(h)
end

