function [Args, LFP, Trains] = LoadMCDfile(FileName)
% CurrentDir = pwd;

Args = []; LFP = []; Trains = [];

switch lower(computer)
    case 'pcwin'
        LIBFILE = 'nsMCDlibrary.dll';
    case 'glnxa64'
        %LIBFILE = 'nsMCDLibraryLinux64.so';
        LIBFILE = '/opt/ICA/nsMCDLibrary.so';
    case 'glnx86'
        LIBFILE = 'nsMCDLibrary.so';
    case 'maci64'
        LIBFILE = 'nsMCDLibrary.dylib';
    otherwise
        msgbox('Unknown architecture (must be either win32, mac os or linux64)!')
        return;
end

if ~isdeployed
    if exist(LIBFILE,'file')
        [pathname, name, ext]=fileparts(which(LIBFILE));
        if (ns_SetLibrary([pathname filesep name ext]) ~= 0)
            msgbox(['Cannot load the library (Valeri):' LIBFILE]);
            return
        end
    else
        msgbox(['Cannot find the library (Valeri):' LIBFILE]);
        return
    end
else
    if ~exist(LIBFILE,'file')
        disp([LIBFILE ' cannot be found (Valeri)']);
        return
    end
    if (ns_SetLibrary(LIBFILE) ~= 0)
        msgbox(['Cannot load the library (Valeri): ' LIBFILE]);
        return
    end
end

[ns_RESULT, hfile] = mexprog(1, FileName); % open file
[nsresult, info]=ns_GetFileInfo(hfile);

nChs = [];
nTrs = [];
for k = 1:info.EntityCount,
    [nsresult,entity] = ns_GetEntityInfo(hfile, k);
    if entity.EntityType == 2, % analog
        nChs = [nChs k];
        nPts = entity.ItemCount;
    end
    if entity.EntityType == 1, % trigger
        nTrs = [nTrs k];
    end
end
n2 = length(nChs);
TLspikes = [0 inf];
Args.ChannelArranged = 'no';
Args.Fs = [];
if ~isempty(nChs),
    answ = inputdlg({'Import analog channels (e.g. [5:30]): ','Time interval (s): ',...
        ['Fs = ' num2str(1e-3/info.TimeStampResolution) ' kHz. Downsample (1 - no, 2 - two times):']},...
        'Importing data', 1,{['[1:' num2str(n2) ']'],...
        ['[0,' num2str(info.TimeSpan) ']'],'1'});
    if isempty(answ), return; end
    idChan = intersect(str2num(answ{1}),1:n2);
    nChs = nChs(idChan);
    TLspikes = str2num(answ{2});
    TLim = floor(str2num(answ{2})/info.TimeStampResolution);
    dSm = str2num(answ{3});
    nL = ceil(diff(TLim)/dSm);
    LFP = zeros(length(nChs),nL);
    FlagWrng = 'off';
    for k = 1:length(nChs),
        [ns_RESULT, ContCount, data] = mexprog(8, hfile, nChs(k) - 1, TLim(1), diff(TLim));
        if ns_RESULT == 0        
            LFP(k,:) = data(1:dSm:end);
        elseif ns_RESULT == -7
            [ns_RESULT, ContCount, data] = mexprog(8, hfile, nChs(k) - 1, 0, nPts);
            LFP(k,1:ceil(nPts/dSm)) = data(1:dSm:nPts);            
        else
            nend = min(10000,0.1*diff(TLim));
            [ns_RESULT, ContCount, data] = mexprog(8, hfile, nChs(k) - 1, TLim(1), nend);
            FlagWrng = 'on';
            LFP(k,1:ceil(nend/dSm)) = data(1:dSm:nend);
        end
    end
    [nsresult,analog] = ns_GetAnalogInfo(hfile, nChs(1));
    Args.Fs = analog.SampleRate/dSm;
    if strcmp(FlagWrng,'on');
        uiwait(warndlg('Serios problems with the file!','warning'));
    end
end

    
if ~isempty(nTrs),
    for k = 1:length(nTrs),
        [nsresult,entity] = ns_GetEntityInfo(hfile, nTrs(k));
        [nsresult,timestamp] = ns_GetEventData(hfile,nTrs(k),1:entity.ItemCount);
        sp = timestamp - TLspikes(1);
        sp(sp < 0) = [];
        sp(sp > diff(TLspikes)) = [];
        Spikes{k} = sp;
    end
    Trains.Spikes = Spikes;
    Trains.Titles = num2str(nTrs(:));
end


% cd(CurrentDir);

Args.FDIR = fileparts(FileName);
Args.FILE = FileName;
Args.T0 = 0;
