function PlotSpikeTrains(s, Tlim, TrainTitles)
%
% PlotSpikeTrains(s, Tlim, TrainTitles)
%    This function plots spike trains
%      Input: 
%         s - cell with spike times
%         Tlim - vector of plot limits in time axis [Tmin, Tmax]
%                default: from the 1st spike to the last
%         TrainTitles - cell of train titles
%                default: {'N1','N2','N3',...}
%
% V. Makarov, vmakarov@opt.ucm.es
% Dec. 2006: release
%
% Feb. 2009: changed order of the trains: now from top to bottom
% Valeri Makarov, vmakarov@mat.ucm.es
%
if nargin < 1 || ~iscell(s), 
    help PlotSpikeTrains
    error('No spike trains'); 
end

N = length(s); % number of spike trains
if nargin < 2 || isempty(Tlim),
    Tlim = [];
    for k = 1:N, 
        if isempty(Tlim),
            Tlim = [min(s{k}), max(s{k})];
        else            
            Tlim(1) = min(Tlim(1),min(s{k}));
            Tlim(2) = max(Tlim(2),max(s{k}));
        end
    end
end

if nargin < 3 || isempty(TrainTitles),
    TrainTitles = [char(ones(N,1)*'N') num2str((1:N)')];
end    
for k = 1:N,
    tr = s{k};
    plot(tr, (N-k+1)*ones(1,length(tr)),'k+','MarkerSize',10);
    hold on;
    plot(Tlim,(N-k+1)*ones(1,2),'k-')
end
xlim(Tlim);
ylim([0,N+1]);
xlabel('time (s)');
set(gca,'YTick',1:N);
set(gca,'YTickLabel', flipud(TrainTitles));
