function WT_Args = SetDefaultWTParameters(Inp)
%
% This function sets and return as a structure 
% DEFAULT parameters for the Wavelet Transform of spike trains
%
% Valeri Makarov
% vmakarov@opt.ucm.es
%
% Feb. 2007, modified (if input is structure, use it)
% Jan. 2007, initial version
%
%

% Default parameter values
fst = 1;
if nargin == 1 && ~isstruct(Inp)
    fst = Inp;
end
rate = 100;
fo  = 2;
Dj  = 1/12;
aSt = 2/rate;
aEn = 3*fo/fst;
b = [];
scrsz = get(0, 'ScreenSize'); 

% If the input is a structure, use those fields that exist
if isstruct(Inp),
    if isfield(Inp,'rate'), rate = Inp.rate; end
    if isfield(Inp,'fo'),   fo  = Inp.fo; end
    if isfield(Inp,'fst'),  fst = Inp.fst; end
    if isfield(Inp,'Dj'),   Dj  = Inp.Dj; end
    if isfield(Inp,'aSt'),  aSt = Inp.aSt; end
    if isfield(Inp,'aEn'),  
        aEn = Inp.aEn;
    else
        aEn = 3*fo/fst;
    end
    if isfield(Inp,'b'),    b   = Inp.b; end
end
    
J1 = round(log2(aEn/aSt)/Dj);  % # of scales
a = aSt*2.^((0:J1)*Dj);        % scales
WT_Args = struct(...
    'rate',rate,...  % frequency rate for time resolution
    'fo',fo,...      % frequency for the Morlet WT
    'fst',fst,...    % frequency of the stimulus
    'Dj',Dj,...      % sub-octaves per octave
    'aSt', aSt,...   % minimal scale
    'aEn', aEn,...   % maximal scale
    'b', b,...       % time grid (empty at the beginning)
    'a', a,...       % vecotor of scales
    'COI',[],...     % cone of influence (empty at the beginning)
    'sig95',[],...   % significance level (empty at the beginning)
    'PPsig95',[],... % significance level for Power Spect (empty at the beginning)
    'PPmean',[],...  % mean of the noise Power Spect (empty at the beginning)
    'FR',[],...      % firing rate
    'ThrType','soft',...    % Method for coherence thresholding (non, hard, soft)
    'ThrFactor',1e-4,...    % Thresholding factor (Thr = factor*max(Wxy))
    'scrsz',scrsz,...       % Screen size 
    'AddFigures', 1,...     % show additional figures (0 - no; 1 - most important; 2 - all)
    'BlackWhite',0);        % plot in colors
    
